<?php namespace Avans;

use Avans\api\api;
use Avans\parts\badge;

class avans
{
    public function __construct()
    {
        $this->define_init();
        add_action('init', array($this,'avans_init'));
        add_action('wp_enqueue_scripts', array($this,'assets_init'));
        add_action('admin_enqueue_scripts', array($this,'assets_init'));
        add_action('woocommerce_init', array($this,'avans_wc_init'));
        add_filter('woocommerce_account_menu_items', array($this,'avans_wc_panel_menu_edit'));

        $settings = (array)AVANS_SETTINGS['panel_settings'];
        if ($settings['show_panel'] == 'true') {
            $root = 'avans-panel';
            if (isset($settings['root_panel']) && !empty($settings['root_panel'])) {
                $root = $settings['root_panel'];
            }
            add_action("woocommerce_account_{$root}_endpoint", array($this,'wc_menu_avans_panel_content'));
        }

        $this->ajax_init();
        $this->class_loader();
    }
    
    public function define_init()
    {
        $this->initialize_settings();
        define("AVANS_PATH", plugin_dir_path(AVANS_PLUGIN));
        define("AVANS_URI", plugin_dir_url(AVANS_PLUGIN));
        define("AVANS_SETTINGS", (array)get_option('avans_plugin_setting', []));
        define("AVANS_SETTINGS_VERSION", '4.0.0');
        define("AVANS_DB_VERSION", '1.0.8');
        define("AVANS_ASSETS_VERSION", '3.5.0');
        define("AVANS_PREFIX", 'avans_');
    }

    public function initialize_settings(){
        $settings = get_option('avans_plugin_setting', []);
        if (empty($settings) && file_exists(plugin_dir_path(AVANS_PLUGIN).'app/settings.txt')) {
            $seirailize_settings = file_get_contents(plugin_dir_path(AVANS_PLUGIN).'app/settings.txt');
            $unserialize_settings = unserialize($seirailize_settings);
            update_option('avans_plugin_setting', $unserialize_settings);
        }
    }


    public function assets_init()
    {
        // wp_enqueue_style("font_awesome_css", 'https://pro.fontawesome.com/releases/v5.10.0/css/all.css');

        if (!is_admin()) {
            wp_enqueue_style("avans_front", AVANS_URI.'assets/css/front.min.css', array(), AVANS_ASSETS_VERSION);
            wp_enqueue_script("avans_front", AVANS_URI.'assets/js/front.min.js', ['jquery'], AVANS_ASSETS_VERSION, true);
        } else {
            wp_enqueue_style("avans_admin", AVANS_URI.'assets/css/admin.min.css', array(), AVANS_ASSETS_VERSION);
            wp_enqueue_script("avans_admin_script", AVANS_URI.'assets/js/admin.min.js', ['jquery','wp-color-picker','avans_select2'], AVANS_ASSETS_VERSION, true);
            wp_enqueue_script('wp-color-picker');
            wp_enqueue_style('wp-color-picker');
        }
                
        wp_register_style("avans_video_style", AVANS_URI.'assets/css/video-js.min.css');
        wp_register_script("avans_select2", AVANS_URI.'assets/js/select2.min.js', ['jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_video_script", AVANS_URI.'assets/js/videojs.min.js', [], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_player", AVANS_URI.'assets/js/player.min.js', ['jquery','avans_video_script','avans_front'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_chart", AVANS_URI.'assets/js/chart.min.js', ['jquery'], AVANS_ASSETS_VERSION, true);

        //presto
        wp_register_script("avans_player_presto", AVANS_URI.'assets/js/uncompile/player_presto.js', ['jquery','avans_front'], AVANS_ASSETS_VERSION, true);


        // add localize
        wp_register_script("avans_config_chart_js", AVANS_URI.'assets/js/localize/chart_config.js', ['avans_chart','jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_score_post_localize_script", AVANS_URI.'assets/js/localize/score_post.js', ['avans_front','jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_score_daily_localize_script", AVANS_URI.'assets/js/localize/score_daily.js', ['avans_front','jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_score_order_localize_script", AVANS_URI.'assets/js/localize/score_order.js', ['avans_front','jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_score_register_script", AVANS_URI.'assets/js/localize/score_register.js', ['avans_front','jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_score_share_link", AVANS_URI.'assets/js/localize/score_share.js', ['avans_front','jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_single_gift_localize_script", AVANS_URI.'assets/js/localize/admin_single_gift_script.js', ['jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_spin_wheel_localize_script", AVANS_URI.'assets/js/localize/admin_spin_wheels_settings.js', ['jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_spin_wheel_shortcode_localize_script", AVANS_URI.'assets/js/localize/spin_wheel.js', ['jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_lottery_settings_localize_script", AVANS_URI.'assets/js/localize/admin_lottery_settings.js', ['jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_badge_settings_localize_script", AVANS_URI.'assets/js/localize/admin_badge_settings.js', ['jquery'], AVANS_ASSETS_VERSION, true);
        wp_register_script('avans_localize_post_rate_script', AVANS_URI.'assets/js/localize/admin_star_rate.js', array(), AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_check_admin_query_localize_script", AVANS_URI.'assets/js/localize/admin_query_arg.js', ['jquery','avans_select2'], AVANS_ASSETS_VERSION, true);
        wp_register_script("avans_lock_post_settings_localize_script", AVANS_URI.'assets/js/localize/admin_post_lock.js', ['jquery','avans_select2'], AVANS_ASSETS_VERSION, true);
    }

    public function ajax_init()
    {
        include_once AVANS_PATH.'includes/front/ajax.php';
        include_once AVANS_PATH.'includes/admin/ajax.php';
    }

    public function avans_init()
    {
        ini_set('display_errors', 0);
        ini_set('display_startup_errors', 0);

        $this->avans_security_init();
        load_plugin_textdomain('avans_plugin', false, dirname(plugin_basename(AVANS_PLUGIN)).'/languages');
        add_image_size('avans_badge_small', 40, 40, true);
        user::avans_create_refere_code();
        include_once AVANS_PATH.'includes/lib/jdf.php';
        include_once AVANS_PATH.'includes/admin/sms/sms.php';
        include_once AVANS_PATH.'templates/shortcodes/shortcodes.php';
        flush_rewrite_rules();
    }

    public function avans_security_init()
    {
        $settings = [
            'name'          => 'Avans Gamification Plugin',
            'slug'          => 'avans_guard',
            'parent_slug'   => 'avans_plugin',
            'text_domain'   => 'avans_plugin',
            'product_token' => 'a0fcf3f8-22ca-402c-b505-35c706bf31b0',
            'option_name'   => 'moh_score_guard_register_settings'
        ];
        security::instance($settings);
    }

    public function avans_wc_init()
    {
        $settings = (array)AVANS_SETTINGS['panel_settings'];
        if ($settings['show_panel'] == 'true') {
            $root = 'avans-panel';
            if (isset($settings['root_panel']) && !empty($settings['root_panel'])) {
                $root = $settings['root_panel'];
            }
            add_rewrite_endpoint($root, EP_ROOT | EP_PAGES);
        }
    }

    public function avans_wc_panel_menu_edit($items)
    {
        $settings = (array)AVANS_SETTINGS['panel_settings'];
        if ($settings['show_panel'] == 'true') {
            $title = 'امتیازهای من';
            if (func::is_set($settings['title_panel'])) {
                $title = $settings['title_panel'];
            }
            $root = 'avans-panel';
            if (func::is_set($settings['root_panel'])) {
                $root = $settings['root_panel'];
            }
            $logout = $items['customer-logout'];
            unset($items['customer-logout']);
            $items[$root] = $title;
            $items['customer-logout'] = $logout;
        }
        return $items;
    }

    public function wc_menu_avans_panel_content()
    {
        echo do_shortcode('[avans-user-panel]');
    }

    public function class_loader()
    {
        if (update::is_need_update()) {
            update_option('avans_db_version', '');
        }
        new db();
        new admin();
        new front();
        new actions();
        new badge();
        new api();
    }
}
