<?php namespace Avans;
class integrations{

    public static function import_score($type){
        switch($type){
            case 'my-cred':
                self::import_score_from_my_cred();
            break; 
            case 'word-point':
                self::import_score_from_word_points();
            break; 
            case 'yith-points-and-rewards':
                self::import_score_from_yitt();
            break; 
            case 'ultimate-points-and-rewards':
                self::import_from_ultimate_point();
            break;
            case 'woocommerce_point_and_rewards':
                self::import_from_woocommerce_point_and_rewards();
            break;
            case 'set_score_last_orders':
                self::import_last_order_score();
            break;
        }
    }

    public static function import_from_woocommerce_point_and_rewards(){
        global $wc_points_rewards, $wpdb;

        $users = get_users();
        foreach ($users as $user):

            $points_balance = 0;

            $query = "SELECT * FROM {$wc_points_rewards->user_points_db_tablename} WHERE user_id = %d AND points_balance != 0";
            $points = $wpdb->get_results( $wpdb->prepare( $query, $user->ID ) );

            // total up the existing points balance
            foreach ( $points as $_points ) {
                $points_balance += $_points->points_balance;
            }

            user::add_log($user->ID, 'import_form_plugins', [['type'=>'woocommerce_point_and_rewards']], (int)$points_balance);
            
        endforeach;
        update_option(AVANS_PREFIX.'import_woocommerce_point_and_rewards',true);
    }

    public static function import_score_from_my_cred(){
        global $wpdb, $mycred_log_table;
        $users = get_users();
        foreach ($users as $user):
            $wheres   = array();
            $wheres[] = $wpdb->prepare("ctype = %s", mycred_get_meta_key('mycred_default'));
            $user->ID = absint($user->ID);
            if ($user->ID != '' && $user->ID != 0) {
                $wheres[] = $wpdb->prepare("user_id = %d", $user->ID);
            }
            $wheres  = implode(" AND ", $wheres);
            $total   = $wpdb->get_var("SELECT SUM( creds ) FROM {$mycred_log_table} WHERE {$wheres};");

            user::add_log($user->ID,'import_form_plugins',[['type'=>'mycred']],(int)$total);
            
        endforeach;
        update_option(AVANS_PREFIX.'import_myCred',true);
    }

    public static function import_score_from_word_points(){
        $users = get_users();
        foreach ($users as $user):
            $points = 0;
            foreach (wordpoints_get_points_types() as $slug => $type) {
                $point = wordpoints_get_points($user->ID, $slug);
                $points += (int)$point;
            }
            user::add_log($user->ID, 'import_form_plugins', [['type'=>'wordpoints']], (int)$points);
        endforeach;
        update_option(AVANS_PREFIX.'import_wordPoints', true);
    }

    public static function import_score_from_yitt(){
        $users = get_users();
        foreach ($users as $user):
        $total = (int)get_user_meta($user->ID, '_ywpar_user_total_points', true);
        user::add_log($user->ID, 'import_form_plugins', [['type'=>'yitt']], (int)$total);
        endforeach;
        update_option(AVANS_PREFIX.'import_yitt', true);
    }

    public static function import_from_ultimate_point(){
        $users = get_users();
        foreach ($users as $user):
            $total = (int)get_user_meta($user->ID, 'mwb_wpr_points', true);
            user::add_log($user->ID, 'import_form_plugins', [['type'=>'ultimate_point']], (int)$total);
        endforeach;
        update_option(AVANS_PREFIX.'import_ultimatePoints', true);
    }

    public static function import_last_order_score(){
        $query = new \WP_Query(array(
            'post_type'=> 'shop_order',
            'post_status'=> 'wc-completed',
            'posts_per_page' => -1
        )); 
        $settings = AVANS_SETTINGS['score_settings']['purchase'];
        foreach ($query->posts as $order) {
            $order_id = $order->ID;
            $last_order_viewed = get_post_meta($order_id, 'score_order_viewed', true);
            $order_viewed = get_post_meta($order_id, AVANS_PREFIX.'order_viewed', true);
            $order = wc_get_order($order_id);
            $user = $order->get_user();
            if (empty($order_viewed) && empty($last_order_viewed) && $user) {
                $price = data::get_total_order($order);
                $sum_score = 0;
                $min_price = !empty($settings['min_price']) ? (int)$settings['min_price'] : 0 ;

                if ($settings['active'] && $order->get_payment_method() != 'wallet' && $price >= $min_price) {
                    $sum_score = data::get_sum_score_for_purchase($user->ID, $order);
                    $is_permision = user::is_permision_get_score('wc_order', $user->ID);
                    $sum_score =  user::get_valid_score($user->ID, $sum_score, true);

                    if ($sum_score > 0 &&  $is_permision) {
                        $details = [
                            array(
                                'key' => 'order_id',
                                'value' => $order_id,
                            )
                        ];
                        user::add_log($user->ID, 'wc_order', $details, $sum_score);
                    }
                }
                update_post_meta($order_id, AVANS_PREFIX.'order_viewed', true);
            }
        }
    }

}