<?php

use Avans\data;
use Avans\func;
use Avans\parts\completeProfile;
use Avans\parts\gifts;
use Avans\user;

function avs_add_score_view_post_types_callback(){

    if(!is_user_logged_in()){
        return;
    }

    $user_id = $_POST['user'];
    $post_id = (int)$_POST['id'];
    $post_type = get_post_type($post_id);

    if( in_array($post_type,data::get_lms_postTypes_support()) ){
        $post_type = 'course';
    }


    $settings = AVANS_SETTINGS['score_settings'][$post_type];
    if($post_type == 'page'){
        $settings = get_post_meta($post_id,AVANS_PREFIX.'meta_score_page',true);
    }

    $post_viewed = (array)get_user_meta($user_id,AVANS_PREFIX.'post_types_viewed',true);
    $post_type_viewed = (array)get_user_meta($user_id, AVANS_PREFIX.$post_type.'_viewed',true);

    if(in_array($post_id,$post_viewed)){
        wp_send_json(array(
            'action-status' => 'current user last viewed current post'
        ));
    }

    if (!user::is_permision_get_score('view-'.$post_type, $user_id)) {
        return;
    }


    array_push($post_viewed,$post_id);
    array_push($post_type_viewed,$post_id);

    $details = array(
        array(
            'key' => 'post-id',
            'value' => $post_id
        )
    );


    if($post_type == 'page'){
        $finalscore = user::add_log($user_id,'view-'.$post_type,$details,(int)$settings['score']);
    }else{
        $finalscore = user::add_log($user_id, 'view-'.$post_type, $details);
    }

    if ($finalscore) {
        update_user_meta($user_id, AVANS_PREFIX.'post_types_viewed', $post_viewed);
        update_user_meta($user_id, AVANS_PREFIX.$post_type.'_viewed', $post_type_viewed);
        do_action('avans_after_view_post_type',$user_id,$post_id);
    }

    wp_send_json(array(
        'success' => $finalscore ? 'true' : 'false',
        'result' => $finalscore ? $finalscore : 'score_is_zero',
    ));
}
add_action('wp_ajax_avs_add_score_view_post_types','avs_add_score_view_post_types_callback');


function avans_calc_single_product_score_callback(){
    $variation_id = $_POST['variation'];
    $product_id = $_POST['product_id'];
    $count = $_POST['qty'];

    $score = data::get_single_product_score(get_current_user_id(),$product_id,$variation_id,$count);
    wp_send_json([
        'score' => $score,
    ]);
}
add_action('wp_ajax_avans_calc_single_product_score','avans_calc_single_product_score_callback');
add_action('wp_ajax_nopriv_avans_calc_single_product_score','avans_calc_single_product_score_callback');

function avs_add_score_daily_visit_callback(){

    if(!is_user_logged_in()){
        return;
    }

    $settings = AVANS_SETTINGS['score_settings']['daily'];
    $user_id = get_current_user_id();

    $time       = jdate('Y-m-d', time());
    $last_visit = get_user_meta($user_id,AVANS_PREFIX.'last_visit', true);
    
    if($time == $last_visit){
        return;
    }

    if (!user::is_permision_get_score('daily-visit', $user_id)) {
        return;
    }
    
    user::add_log($user_id,'daily-visit');

    $last_visit = update_user_meta($user_id,AVANS_PREFIX.'last_visit', $time);

    wp_send_json([
        'success' => true,
        'show_toast' => true,
    ], 200);

}
add_action('wp_ajax_avs_add_score_daily_visit','avs_add_score_daily_visit_callback');


function avs_add_score_share_links_callback(){

    $user = (int)$_POST['referer'];

    if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
        $ip = $_SERVER['HTTP_CLIENT_IP'];
    } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
        $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
    } else {
        $ip = $_SERVER['REMOTE_ADDR'];
    }

    if(!Avans\data::is_visit($ip,$_POST['post_id'])){

        if (!user::is_permision_get_score('share-link', $user)) {
            return;
        }

        $result = Avans\data::add_visit($ip,$_POST['post_id']);
        if(!is_wp_error( $result )){
            $details = [
                array(
                    'key' => 'post_id',
                    'value' => $_POST['post_id']
                )
            ];
            Avans\user::add_log($user,'share-link',$details);
            do_action('avans_after_share_post',get_user_by('ID',$user),$_POST['post_id']);

            $post_id = (array)$_POST['share_viewed'];
            array_push($post_id,$_POST['post_id']);
            setcookie('avans_share_viewed', implode("-",$post_id) , (time() + 86400), "/");
        }

    }

}
add_action('wp_ajax_avs_add_score_share_links','avs_add_score_share_links_callback');
add_action('wp_ajax_nopriv_avs_add_score_share_links','avs_add_score_share_links_callback');


function avs_add_score_view_player_callback(){

    if (!is_user_logged_in()) {
        return;
    }

    $user = wp_get_current_user();
    $score = $_POST['score'];
    $player_id = $_POST['player_id'];

    $details = array(
        array(
            'key' => 'post_id',
            'value' => $_POST['post_id'],
        ),
        array(
            'key' => 'object_id',
            'value' => $_POST['object_id'],
        )
    );
    
    if ($_POST['type'] == 'video') {
        $video_viewed = (array)get_user_meta($user->ID, AVANS_PREFIX.'video_viewed', true);
        if (!in_array($player_id, $video_viewed)) {
            array_push($video_viewed, $player_id);
            if (!user::is_permision_get_score('view-video', $user->ID)) {
                return;
            }
            update_user_meta($user->ID, AVANS_PREFIX.'video_viewed', $video_viewed);

            Avans\user::add_log($user->ID,'view-video',$details,(int)$score);

            do_action('avans_after_view_video',$user,$player_id,$video_viewed, $_POST['post_id']);
            
            wp_send_json([
            'success' => true,
        ], 200);
        }
    }

    if ($_POST['type'] == 'sound') {
        $sound_viewed = (array)get_user_meta($user->ID, AVANS_PREFIX.'sound_viewed', true);
        if (!in_array($player_id, $sound_viewed)) {
            array_push($sound_viewed, $player_id);

            if (!user::is_permision_get_score('view-sound', $user->ID)) {
                return;
            }

            update_user_meta($user->ID, AVANS_PREFIX.'sound_viewed', $sound_viewed);

            Avans\user::add_log($user->ID,'view-sound',$details,(int)$score);

            do_action('avans_after_listen_podcasts', $user, $player_id, $sound_viewed, $_POST['post_id']);

            wp_send_json([
            'success' => true,
        ], 200);
        }
    }

}
add_action('wp_ajax_avs_add_score_view_player','avs_add_score_view_player_callback');



function avans_search_user_logs_callback(){
    $args = [];

    $args['where'] = true;
    if (isset($_GET['type']) && !empty($_GET['type'])) {
        $args['include']['type'] = $_GET['type'];
    }

    $args['include']['user'] = get_current_user_id();

    if (isset($_GET['from']) && !empty($_GET['from'])) {
        $args['time']['from'] = Avans\func::convert_jalali_to_miladi($_GET['from']);
    }
    if (isset($_GET['to']) && !empty($_GET['to'])) {
        $args['time']['to'] = Avans\func::convert_jalali_to_miladi($_GET['to']);
    }
    if (isset($_GET['page']) && !empty($_GET['page'])) {
        $args['page'] = $_GET['page'];
    }

    $logs = Avans\data::get_logs($args);
    include_once AVANS_PATH.'templates/front/panel/content/sections/reports-main.php';

    die;
}
add_action('wp_ajax_avans_search_user_logs','avans_search_user_logs_callback');

function avans_search_gifts_list_callback(){
    $args = [
        'post_type'        => 'avans-gift',
        'posts_per_page'  => 3,
    ];
    if(isset($_GET['page'])){
        $args['paged'] = (int)$_GET['page'];
    }
    $gifts = Avans\data::get_gifts($args);
    include_once AVANS_PATH.'templates/front/panel/content/sections/gift-tabs/all-gift.php';
    die;

}
add_action('wp_ajax_avans_search_gifts_list', 'avans_search_gifts_list_callback');

function avans_get_single_page_gift_callback(){
    $id = $_GET['id'];
    include_once AVANS_PATH.'templates/front/panel/content/sections/gift-single.php';
    die;
}
add_action('wp_ajax_avans_get_single_page_gift','avans_get_single_page_gift_callback');

function avans_get_gifts_for_user_callback()
{
    $gift_id = $_GET['giftid'];
    $option = get_post_meta($gift_id, AVANS_PREFIX.'gift_settings', true);
    $data = Avans\user::add_gift_to_user( (int)$gift_id , (int)get_current_user_id() );
    $created_at = strtotime($data->create_at);
    if ($data) {
        include_once AVANS_PATH.'templates/front/panel/content/sections/gift-results.php';
    }
    die;
}
add_action('wp_ajax_avans_get_gifts_for_user', 'avans_get_gifts_for_user_callback');

function avans_get_details_badge_callback(){
    $user_id = get_current_user_id();
    $badge_id = (int)$_GET['id'];
    do_action('avans_before_badge_details',$user_id,$badge_id);
    include AVANS_PATH.'templates/front/panel/content/sections/badge-details.php';
    die;
}
add_action("wp_ajax_avans_get_details_badge","avans_get_details_badge_callback");


function avans_loade_getted_gifts_tab_callback(){
    $page = isset($_GET['page']) ? $_GET['page'] : 1;
    $data = Avans\user::get_user_getted_gifts(get_current_user_id(),$page);
    include AVANS_PATH.'templates/front/panel/content/sections/gift-tabs/getted-gift.php';
    die;
}
add_action('wp_ajax_avans_loade_getted_gifts_tab','avans_loade_getted_gifts_tab_callback');

function avans_loade_all_gifts_tab_callback()
{
    $gifts = Avans\data::get_gifts();
    include AVANS_PATH.'templates/front/panel/content/sections/gift-tabs/all-gift.php';
    die;
}
add_action('wp_ajax_avans_loade_all_gifts_tab', 'avans_loade_all_gifts_tab_callback');

function avans_convert_wallet_callback(){
    $convert = user::convert_wallet(get_current_user_id());
    wp_send_json([
        'success' => $convert->success,
        'message' => $convert->message,
    ]);
}
add_action('wp_ajax_avans_convert_wallet', 'avans_convert_wallet_callback');

function avans_get_prize_spin_wheel_callback(){

    if(!isset($_POST['wheel_id']) || get_post_type($_POST['wheel_id']) != 'avans-spin-wheel'){
        wp_send_json(['erorr' => 'The "wheel_id" parameter is not set or is set incorrectly!'],404);
    }

    wp_send_json([
        'result' => Avans\user::get_prize_spin_wheel(get_current_user_id(),(int)$_POST['wheel_id']),
    ]);

}
add_action('wp_ajax_avans_get_prize_spin_wheel','avans_get_prize_spin_wheel_callback');


function avans_get_result_spin_wheel_callback(){
    $data = $_GET['response'];

    $option = [
        'avans_type_gift' => $data['type'],
        'type_prize' => 'spin_wheel'
    ];
    $created_at = strtotime($data->create_at);
    include_once AVANS_PATH.'templates/front/panel/content/sections/gift-results.php';
    die;
}
add_action('wp_ajax_avans_get_result_spin_wheel','avans_get_result_spin_wheel_callback');


function avans_get_tickets_for_lottery_callback(){
    if (!isset($_POST['count']) || !isset($_POST['lottery_id'])) {
        wp_send_json(['erorr' => 'The parameters is not set or is set incorrectly!'],404);
    }
    $result = user::get_lottery_tickets($_POST['lottery_id'],$_POST['count'],get_current_user_id());
    
    
    wp_send_json(['success' => $result->success,'message'=>$result->message]);
    
}
add_action('wp_ajax_avans_get_tickets_for_lottery','avans_get_tickets_for_lottery_callback');


function avans_set_star_rate_post_callback(){
    $post_id = $_POST['post_id'];
    $rate = $_POST['rate'];
    $user_id = get_current_user_id();
    if(!empty($post_id) && !empty($rate) && $user_id > 0){
        $rate = Avans\data::set_star_rate_post($post_id,$rate,$user_id);
        $text = '';
        if((int)$rate['score'] > 0){
            $settings = AVANS_SETTINGS['score_settings']['post-rating'];
            $text  = "شما بابت امتیازدهی به این مطلب ".$rate['score']." ".func::get_score_label()." "."گرفتید" ;
            if (!empty($settings['text'])) {
                $text  = str_replace("{score}", $rate['score'] , $settings['text']);
            }
        }

        $star = data::get_data_star_rate_post($post_id,$user_id);

        wp_send_json([
            'meta' => sprintf(__('امتیاز %s از %s رای','avans-plugin'),strval(number_format($star->rate,2)),$star->count),
            'success'=>true,
            'text' => $text,
            'score'=> (int)$rate['score'],
            'rate' => $rate['avg']
        ]);
    }
    wp_send_json(['success'=>false,'status' => 'not permision'],403);
}

add_action('wp_ajax_avans_set_star_rate_post','avans_set_star_rate_post_callback');


function avans_check_complete_user_info_callback()
{

    $errors = [];
    $settings = AVANS_SETTINGS['panel_settings']['user_complete'];

    if (!func::is_set($settings['show_name']) || $settings['show_name'] == 'true') {
        if (!isset($_POST['firstname']) || gettype($_POST['firstname']) != 'string' || strlen($_POST['firstname']) > 40 ) {
            $errors[]  = [
                'type' => 'firstname',
                'message' => 'نام را با فرمت صحیح وارد نمایید.'
            ];
        }
    }


    if (!func::is_set($settings['show_last_name']) || $settings['show_last_name'] == 'true') {
        if (!isset($_POST['lastname']) || gettype($_POST['lastname']) != 'string' || strlen($_POST['lastname']) > 40) {
            $errors[]  = [
                'type' => 'lastname',
                'message' => 'نام خانوادگی را با فرمت صحیح وارد نمایید.'
            ];
        }
    }

    if (!func::is_set($settings['show_birthdate']) || $settings['show_birthdate'] == 'true') {
        if (!isset($_POST['birthdate']) || !data::avans_is_valid_date($_POST['birthdate'])) {
            $errors[]  = [
                'type' => 'birthdate',
                'message' => 'تاریخ تولد را با فرمت صحیح وارد نمایید.'
            ];
        }
    }

    if (!func::is_set($settings['show_mobile']) || $settings['show_mobile'] == 'true') {
        if (!isset($_POST['mobile']) && strlen($_POST['mobile']) < 16) {
            $errors[]  = [
                'type' => 'mobile',
                'message' => 'شماره موبایل را با فرمت صحیح وارد نمایید.',
                'len' => strlen($_POST['mobile'])
            ];
        }
    }

    if (!func::is_set($settings['show_email']) || $settings['show_email'] == 'true') {
        if (!isset($_POST['email']) || !is_email($_POST['email'])) {
            $errors[]  = [
                'type' => 'email',
                'message' => 'ایمیل را با فرمت صحیح وارد نمایید.'
            ];
        }
    }

    if (!func::is_set($settings['show_avatar']) || $settings['show_avatar'] == 'true') {
        if (!isset($_POST['last_avatar']) && !isset($_FILES['avatar'])) {
            $errors[]  = [
                'type' => 'avatar',
                'message' => 'تصویر کاربری به درستی انتخاب یا آپلود نشده است!'
            ];
        }
    }

    if (count($errors) > 0) {
        wp_send_json([
            'success' => false,
            'error' => $errors,
        ]);
    }

    if(isset($_FILES['avatar']) && (!func::is_set($settings['show_avatar']) || $settings['show_avatar'] == 'true') ){

        if(!empty($_FILES['avatar']['tmp_name'])){
            $upload = completeProfile::update_avatar(get_current_user_id(), $_FILES['avatar']);
            if (!$upload) {
                $errors[]  = [
                    'type' => 'upload',
                    'message' => 'خطا سرور در بارگزاری تصویر کاربری!'
                ];
            }
        }else{
            $errors[]  = [
                'type' => 'avatar',
                'message' => 'خطا در بارگزاری تصویر کاربری!'
            ];
        }

    }
    

    if (count($errors) > 0) {
        wp_send_json([
            'success' => false,
            'error' => $errors,
        ]);
    }

    $user_id = get_current_user_id();
    $status = completeProfile::set_user_info($user_id , $_POST);
    $score = completeProfile::apply_score_for_complete_user_info($user_id);

    if ((int)$score > 0) {
        $settings = AVANS_SETTINGS['score_settings']['complete-profile'];
        $unit = func::get_score_label();
        $text = "شما بابت تکمیل و تایید اطلاعات حساب کاربریتان $score $unit گرفتید" ;
        if (!empty($settings['text'])) {
            $text  = str_replace("{score}", $score, $settings['text']);
        }
    }



    wp_send_json([
        'success' => is_object($status) ? true : $status,
        'data' => $status,
        'error' => $errors,
        'score' => $score,
        'text' => $text
    ]);
}
add_action('wp_ajax_avans_check_complete_user_info', 'avans_check_complete_user_info_callback');


function avans_confirm_data_type_user_info_callback(){
    $type = $_POST['type'];
    $code = $_POST['value'];
    $user_id = get_current_user_id();
    $option = [
        'plugin_uri' => AVANS_URI,
    ];


    $valid_type = ['mobile','email'];

    if(!func::is_set($type) || !in_array($type,$valid_type) || !func::is_set($code) || completeProfile::is_validation($user_id,$type)){
        return;
    }

    $status = completeProfile::is_valid_user_code_inserted($user_id,$type,$code);

    $score = completeProfile::apply_score_for_complete_user_info($user_id);

    if ((int)$score > 0) {
        $settings = AVANS_SETTINGS['score_settings']['complete-profile'];
        $unit = func::get_score_label();
        $text = "شما بابت تکمیل و تایید اطلاعات حساب کاربریتان $score $unit گرفتید" ;
        if (!empty($settings['text'])) {
            $text  = str_replace("{score}", $score, $settings['text']);
        }
    }

    wp_send_json([
        'success' => $status,
        'score' => $score,
        'text' => $text
     ]);

}
add_action('wp_ajax_avans_confirm_data_type_user_info', 'avans_confirm_data_type_user_info_callback');



function avans_resend_code_validation_callback(){
    $type = $_POST['type'];
    $user_id = get_current_user_id();

    if(!func::is_set($type)){
        return;
    }

    if(completeProfile::is_validation($user_id,$type)){
        return;
    }

    $status = completeProfile::resend_verification_code($user_id,$type);
    
    wp_send_json([
        'success' => $status,
    ]);

}
add_action('wp_ajax_avans_resend_code_validation','avans_resend_code_validation_callback');



function avans_save_shipping_info_callback(){
    $data = $_POST['info'];
    $order_id = $_POST['order_id'];
    $errors = false;
    if(!func::is_set($data['name']) || strlen($data['name']) > 300){
       $errors = true; 
    }

    if(!func::is_set($data['lastname']) || strlen($data['lastname']) > 300){
       $errors = true; 
    }

    if(!func::is_set($data['state']) || strlen($data['state']) > 300){
       $errors = true; 
    }

    if(!func::is_set($data['city']) || strlen($data['city']) > 300){
       $errors = true; 
    }

    if(!func::is_set($data['address']) || strlen($data['address']) > 300){
       $errors = true; 
    }

    if(!func::is_set($data['zipcode']) || strlen(func::toEnNumber($data['zipcode'])) != 10){
       $errors = true; 
    }

    if(!func::is_set($data['mobile']) || strlen(func::toEnNumber($data['mobile'])) != 11){
       $errors = true; 
    }

    if($errors){
        wp_send_json([
            'success' => false,
        ]);
    }

    $order = wc_get_order( $order_id );

    update_post_meta( $order_id, '_billing_first_name', sanitize_text_field($data['name'])  );
    update_post_meta( $order_id, '_billing_last_name', sanitize_text_field($data['lastname'])  );
    update_post_meta( $order_id, '_billing_state', sanitize_text_field($data['state'])  );
    update_post_meta( $order_id, '_billing_city', sanitize_text_field($data['city'])  );
    update_post_meta( $order_id, '_billing_address_1', sanitize_text_field($data['address'])  );
    update_post_meta( $order_id, '_billing_postcode', sanitize_text_field($data['zipcode'])  );
    update_post_meta( $order_id, '_billing_phone', sanitize_text_field($data['mobile'])  );
    update_post_meta( $order_id ,'_billing_country','IR');

    wp_send_json([
        'success' => true,
        'state' => WC()->countries->get_states( 'IR' )[sanitize_text_field($data['state'])],
    ]);
}
add_action("wp_ajax_avans_save_shipping_info","avans_save_shipping_info_callback");